export path=($path $HOME/.config/dotfiles/bin)
export fpath=($fpath $ZDOTDIR/local/fpath)
export FZF_MARKS_FILE="$HOME/.config/fzfmarks"
export STARSHIP_CONFIG="$ZDOTDIR/starship.toml"
export ZSH_CACHE_PATH="$HOME/.cache/zsh/compcache/"

# Stuff
setopt auto_cd
setopt multios
setopt prompt_subst
setopt auto_pushd
setopt pushd_ignore_dups
setopt pushdminus

mkdir -p $HOME/.cache/zsh

# Zinit Clone if not exist
if [[ ! -f $HOME/.config/zinit/bin/zinit.zsh ]]; then
    command git clone https://github.com/zdharma/zinit $HOME/.config/zinit/bin
fi

# Zinit
declare -A ZINIT
ZINIT[BIN_DIR]="$HOME/.config/zinit/bin"
ZINIT[HOME_DIR]="$HOME/.config/zinit"
ZINIT[ZCOMPDUMP_PATH]="$HOME/.cache/zsh/compdump"

source $HOME/.config/zinit/bin/zinit.zsh
autoload -U +X bashcompinit

# Theme
eval "$(starship init zsh)"

# Programs
zinit ice as"program" from"gh-r" mv"fd* -> fd" pick"fd/fd"; zinit light sharkdp/fd
zinit ice as"program" from"gh-r" mv"bat* -> bat" pick"bat/bat"; zinit light sharkdp/bat
zinit ice as"program" from"gh-r" mv"exa* -> exa"; zinit light ogham/exa
zinit ice as"program" from"gh-r" mv"pet* -> pet" pick"usr/local/bin/pet"; zinit light knqyf263/pet

# Completions and Autosuggestions
zinit ice wait lucid blockf atpull'zinit creinstall -q .'; zinit light zsh-users/zsh-completions
zinit ice wait lucid atload"_zsh_autosuggest_start"; zinit light zsh-users/zsh-autosuggestions

# Needed
source $ZDOTDIR/files/dircolor.zsh
source $ZDOTDIR/files/aliases.zsh
source $ZDOTDIR/files/history.zsh
source $ZDOTDIR/files/direnv.zsh
zinit snippet OMZL::functions.zsh
zinit snippet OMZL::completion.zsh
zinit snippet OMZL::directories.zsh
zinit snippet OMZL::key-bindings.zsh
zinit snippet OMZL::termsupport.zsh
zinit snippet OMZL::clipboard.zsh
zinit snippet OMZL::grep.zsh
zinit snippet OMZP::sudo
zinit snippet OMZP::command-not-found
zinit snippet OMZP::fzf
zinit snippet OMZP::lando

# Completion Stuff
zstyle ':completion:*' list-colors ${(s.:.)LS_COLORS}
zstyle ':completion:*:*:*:users' ignored-patterns '*'
zstyle -e ':completion:*:(ssh|scp|sftp|rsh|rsync):hosts' hosts 'reply=(${=${${(f)"$(cat {/etc/ssh_,~/.ssh/known_}hosts(|2)(N) /dev/null)"}%%[# ]*}//,/ })'
zstyle ':completion:*:(scp|rsync):*' tag-order 'hosts:-host:host hosts:-domain:domain hosts:-ipaddr:ip\ address *'
zstyle ':completion:*:(scp|rsync):*' group-order users files all-files hosts-domain hosts-host hosts-ipaddr
zstyle ':completion:*:ssh:*' tag-order users 'hosts:-host:host hosts:-domain:domain hosts:-ipaddr:ip\ address *'
zstyle ':completion:*:ssh:*' group-order hosts-domain hosts-host users hosts-ipaddr
zstyle ':completion:*:(ssh|scp|rsync):*:hosts-host' ignored-patterns '*(.|:)*' loopback ip6-loopback localhost localhost4 localhost6 ip6-localhost broadcasthost pxm
zstyle ':completion:*:(ssh|scp|rsync):*:hosts-domain' ignored-patterns '<->.<->.<->.<->' '^[-[:alnum:]]##(.[-[:alnum:]]##)##' '*@*' '*localdomain*' '*.eeleater.org' '*sublime*' '*.local'
zstyle ':completion:*:(ssh|scp|rsync):*:hosts-ipaddr' ignored-patterns '^(<->.<->.<->.<->|(|::)([[:xdigit:].]##:(#c,2))##(|%*))' '127.0.0.<->' '255.255.255.255' '::1' 'fe80::*'

eval "$(fasd --init auto)"
zinit ice wait lucid; zinit light wookayin/fzf-fasd
zinit ice wait lucid; zinit light urbainvaes/fzf-marks
zinit ice wait lucid; zinit light voronkovich/gitignore.plugin.zsh
zinit ice wait lucid; zinit light reegnz/jq-zsh-plugin
zinit ice wait lucid; zinit light asdf-vm/asdf
zinit ice wait lucid; zinit light Aloxaf/fzf-tab

# syntax highlighting
zpcompinit
bashcompinit
zinit ice wait lucid atinit"zpcdreplay -q"; zinit light zsh-users/zsh-syntax-highlighting

# Local RC
[[ -f "$ZDOTDIR/local/rc.zsh" ]] && source "$ZDOTDIR/local/rc.zsh"
